@@ -1,10 +1,12 @@
-from __future__ import annotations
+# Copyright (c) QuantCo and pydiverse contributors 2025-2025
+# SPDX-License-Identifier: BSD-3-Clause
 
-from typing import TYPE_CHECKING, Callable, Dict, List, Tuple, TypeVar, Union
+from typing import TYPE_CHECKING, Callable, TypeVar, Union
 
 if TYPE_CHECKING:
     from pydiverse.pipedag import Blob, Table
-    from pydiverse.pipedag.backend import BaseTableStore
+    from pydiverse.pipedag.materialize.store import BaseTableStore
+    from pydiverse.pipedag.materialize.table_hook_base import TableHookResolver
 
 
 def decorator_hint(decorator: Callable) -> Callable:
@@ -15,6 +17,7 @@ def decorator_hint(decorator: Callable) -> Callable:
 T = TypeVar("T")
 CallableT = TypeVar("CallableT", bound=Callable)
 StoreT = TypeVar("StoreT", bound="BaseTableStore")
+TableHookResolverT = TypeVar("TableHookResolverT", bound="TableHookResolver")
 
 # Materializable
 MPrimitives = Union[int, float, bool, str]
@@ -23,7 +26,7 @@ MTypes = Union["Table", "Blob"]
 BaseMaterializable = Union[MPrimitives, MTypes]
 Materializable = Union[
     BaseMaterializable,
-    Dict[str, "Materializable"],
-    List["Materializable"],
-    Tuple["Materializable", ...],
+    dict[str, "Materializable"],
+    list["Materializable"],
+    tuple["Materializable", ...],
 ]
