@@ -17,6 +17,7 @@ __all__ = [
     "RenameSchema",
     "DropSchemaContent",
     "CreateTableAsSelect",
+    "CreateEmptyTableAsSelect",
     "InsertIntoSelect",
     "CreateTableWithSuffix",
     "CreateViewAsSelect",
@@ -135,6 +136,26 @@ class CreateTableAsSelect(DDLElement):
         self.suffix = suffix
 
 
+class CreateEmptyTableAsSelect(DDLElement):
+    def __init__(
+        self,
+        name: str,
+        schema: Schema,
+        query: Select | TextClause | sa.Text,
+        *,
+        unlogged: bool = False,
+        suffix: str = "",
+    ):
+        self.name = name
+        self.schema = schema
+        self.query = query
+        # Postgres supports creating unlogged tables. Flag should get ignored by
+        # other dialects
+        self.unlogged = unlogged
+        # Suffix to be appended to the statement, e.g. from materialization details
+        self.suffix = suffix
+
+
 class CreateTableWithSuffix(DDLElement):
     def __init__(
         self,
@@ -723,6 +744,20 @@ def visit_insert_into_select_mssql(insert: InsertIntoSelect, compiler, **kw):
     return _visit_fill_obj_as_select(insert, compiler, "", kw, cmd="INSERT INTO", sep=" WITH(TABLOCKX)")
 
 
+@compiles(InsertIntoSelect, "ibm_db_sa")
+def visit_insert_into_select_ibm_db2_load(insert: InsertIntoSelect, compiler, **kw):
+    name = compiler.preparer.quote(insert.name)
+    schema = compiler.preparer.format_schema(insert.schema.get())
+    kw["literal_binds"] = True
+    select = compiler.sql_compiler.process(insert.query, **kw)
+    # using LOAD is much faster than an actual INSERT INTO for DB2
+    tick = "'"
+    return (
+        f"CALL SYSPROC.ADMIN_CMD('load from ({select.replace(tick, tick + tick)}) of cursor REPLACE RESETDICTIONARY "
+        f"into {schema}.{name} STATISTICS YES NONRECOVERABLE')"
+    )
+
+
 @compiles(CreateTableAsSelect)
 def visit_create_table_as_select(create: CreateTableAsSelect, compiler, **kw):
     return _visit_fill_obj_as_select(create, compiler, "TABLE", kw)
@@ -749,8 +784,23 @@ def visit_create_table_as_select_mssql(create: CreateTableAsSelect, compiler, **
 
 @compiles(CreateTableAsSelect, "ibm_db_sa")
 def visit_create_table_as_select_ibm_db_sa(create: CreateTableAsSelect, compiler, **kw):
-    # Attention: for DB2, a CreateTableAsSelect must be followed by an InsertIntoSelect
-    # to actually fill data
+    # IBM DB2 cannot create table and fill it in one statement
+    insert_args = create.__dict__
+    del insert_args["unlogged"]
+    del insert_args["suffix"]
+    statements = [CreateEmptyTableAsSelect(**create.__dict__), InsertIntoSelect(**insert_args)]
+    return join_ddl_statements(statements, compiler, **kw)
+
+
+@compiles(CreateEmptyTableAsSelect)
+def visit_create_empty_table_as_select(create: CreateEmptyTableAsSelect, compiler, **kw):
+    _ = create, compiler, kw
+    # by default, dialects do not need to execute different CreateTableAsSelect statement for empty tables
+    raise NotImplementedError()
+
+
+@compiles(CreateEmptyTableAsSelect, "ibm_db_sa")
+def visit_create_empty_table_as_select_ibm_db_sa(create: CreateEmptyTableAsSelect, compiler, **kw):
     suffix = ") DEFINITION ONLY " + create.suffix
     return _visit_fill_obj_as_select(create, compiler, "TABLE", kw, prefix="(", suffix=suffix)
 
