@@ -232,8 +232,8 @@ def _sql_apply_materialize_annotation(
         schema = store.write_subquery(query, table_name, neighbor_table=table, unlogged=unlogged, suffix=suffix)
         return pdt.Table(table_name, pdt.SqlAlchemy(store.engine, schema=schema.get()))
 
-    def materialize_hook(tbl: pdt.Table, table_prefix):
-        name = table_prefix or ""
+    def materialize_hook(tbl: pdt.Table, table_prefix: str | None):
+        name = table_prefix or "_t_"
         name += stable_hash(str(random.randbytes(8)))[0:6]
         intermediate_tbls.append(name)
         return write_pdt_table(tbl, name)
@@ -242,7 +242,7 @@ def _sql_apply_materialize_annotation(
         if inspect.isclass(table.annotation) and issubclass(table.annotation, cs.ColSpec):
             column_spec = table.annotation
             if pdt_new is not None:
-                supported_dialects = ["duckdb", "sqlite", "postgresql", "mssql"]
+                supported_dialects = ["duckdb", "sqlite", "postgresql", "mssql", "ibm_db_sa"]
                 if store.engine.dialect.name in supported_dialects:
                     intermediate_tbls = []
                     cfg = cs.config.Config.default
@@ -429,7 +429,11 @@ class SQLAlchemyTableHook(TableHook[SQLTableStore]):
         unlogged: bool,
     ):
         limit_query = store.get_limit_query(query, rows=0)
-        store.execute(cls._create_as_select_statements(table.name, schema, limit_query, store, suffix, unlogged))
+        store.execute(
+            cls._create_as_select_statements(
+                table.name, schema, limit_query, store, suffix, unlogged, guaranteed_empty=True
+            )
+        )
         store.add_indexes_and_set_nullable(table, schema, on_empty_table=True)
         statements = store.lock_table(table, schema)
         statements += store.lock_source_tables(source_tables)
@@ -449,8 +453,10 @@ class SQLAlchemyTableHook(TableHook[SQLTableStore]):
         store: SQLTableStore,
         suffix: str,
         unlogged: bool,
+        guaranteed_empty: bool = False,
     ):
-        _ = store
+        # most dialects don't need to know whether CreateTableAsSelect executes an empty insert or not
+        _ = store, guaranteed_empty
         return [
             CreateTableAsSelect(
                 table_name,
@@ -1046,20 +1052,42 @@ class PolarsTableHook(TableHook[SQLTableStore], DataframeSqlTableHook):
         # We try to use arrow_odbc (see mssql) or adbc (e.g. adbc-driver-postgresql)
         # if possible. Duckdb also has its own implementation.
         connection_uri = store.engine_url.render_as_string(hide_password=False)
+        df = None
         if cls.dialect_has_adbc_driver():
             try:
                 df = pl.read_database_uri(query, connection_uri, engine="adbc")
                 return cls._fix_dtypes(df, dtypes)
             except:  # noqa
-                store.logger.warning(
-                    "Failed retrieving query using ADBC, falling back to Pandas: %s",
-                    query,
-                )
+                msg = "Failed retrieving query using ADBC, falling back to Pandas: %s"
+                if store.engine.dialect.name == "postgresql":
+                    try:
+                        import adbc_driver_postgresql
+                    except ImportError:
+                        msg = (
+                            "Failed retrieving query using ADBC. Please install adbc-driver-postgresql. "
+                            "Falling back to Pandas: %s"
+                        )
+
+                store.logger.warning(msg, query)
         elif cls.dialect_supports_connectorx():
             # This implementation requires connectorx which does not work for duckdb or ibm_db2.
             # Attention: In case this call fails, we simply fall-back to pandas hook.
-            df = pl.read_database_uri(query, connection_uri)
-        else:
+            try:
+                df = pl.read_database_uri(query, connection_uri)
+            except:  # noqa
+                msg = "Failed retrieving query using ConnectorX, falling back to Pandas: %s"
+                try:
+                    import adbc_driver_postgresql
+
+                    _ = adbc_driver_postgresql
+                except ImportError:
+                    msg = (
+                        "Failed retrieving query using ConnectorX. Please install connectorx. "
+                        "Falling back to Pandas: %s"
+                    )
+                store.logger.warning(msg, query)
+
+        if not df:
             # Polars internally falls back to pandas which results in data dependent types
             df = pl.read_database(query, store.engine)
         return cls._fix_dtypes(df, dtypes)
