@@ -1,4 +1,7 @@
-from __future__ import annotations
+# Copyright (c) QuantCo and pydiverse contributors 2025-2025
+# SPDX-License-Identifier: BSD-3-Clause
+
+from pydiverse.common.errors import DisposedError
 
 
 class FlowError(Exception):
@@ -13,6 +16,12 @@ class StageError(Exception):
     """
 
 
+class GroupNodeError(Exception):
+    """
+    Exception raised when something is wrong with the stage.
+    """
+
+
 class CacheError(Exception):
     """
     Exception raised if something couldn't be retrieved from the cache.
@@ -44,8 +53,27 @@ class RemoteProcessError(IPCError):
     """
 
 
-class DisposedError(Exception):
+class HookCheckException(Exception):
     """
-    Exception raise when an object has been disposed, but some attributes are
-    being accessed nevertheless.
+    Exception raised if a hook check fails. It is caught to surface as a
+    normal task failure.
     """
+
+
+class StoreIncompatibleException(Exception):
+    """
+    Exception raised if a store is incompatible for retrieving a table type.
+    """
+
+
+__all__ = [
+    "FlowError",
+    "StageError",
+    "GroupNodeError",
+    "CacheError",
+    "LockError",
+    "DuplicateNameError",
+    "IPCError",
+    "RemoteProcessError",
+    "DisposedError",
+]
